==> visual-third-party-1.5.1-richnco-sources.jar: com/tenqube/visual_third/ui/NotificationDialogFragment.java <==
package com.tenqube.visual_third.ui;

import android.app.Dialog;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.text.Html;
import android.view.View;
import android.view.Window;
import android.widget.Button;
import android.widget.TextView;

import com.tenqube.visual_third.R;
import com.tenqube.visual_third.util.FontUtil;

import static com.tenqube.visual_third.util.FontUtil.setAllTextView;


public class NotificationDialogFragment extends DialogFragment {

    public static final String TAG = NotificationDialogFragment.class.getSimpleName();


    public NotificationDialogFragment() {
        super();
    }

    Callback callback;

    public static NotificationDialogFragment newInstance(){
        return new NotificationDialogFragment();
    }

    public void setCallback(Callback callback) {
        this.callback = callback;
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {

        try {

            android.app.AlertDialog.Builder builder = new android.app.AlertDialog.Builder(getContext());
            View view = getActivity().getLayoutInflater().inflate(R.layout.dialog_notification,null);
            setAllTextView(view);

            Typeface bold = FontUtil.getFont(getActivity(), FontUtil.MEDIUM);
            TextView title = view.findViewById(R.id.title);
            title.setTypeface(bold);

            TextView content = view.findViewById(R.id.content);
            String contentText = "<font color=\"#606060\">결제 관련 문자와 앱 알림 연동을 위해<br>휴대전화의</font>" +
                    "                        <font color=\"#ff8a00\">'설정 > 잠금화면 및 보안 ><br> 기타 보안 설정 > 알림 접근 허용'</font>"+
                    "                        <font color=\"#606060\">에서<br>굿리치를 허용해주세요.</font>";


            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
                content.setText(Html.fromHtml(contentText, Html.FROM_HTML_MODE_COMPACT));
            } else {
                content.setText(Html.fromHtml(contentText));
            }

            Button okButton = view.findViewById(R.id.ok);

            okButton.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    dismissAllowingStateLoss();
                    if(callback != null) {
                        callback.onOkButtonClicked();
                    }
                }
            });

            Button cancelButton = view.findViewById(R.id.cancel);

            cancelButton.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    dismissAllowingStateLoss();
                    if(callback != null) {
                        callback.onCancelButtonClicked();
                    }
                }
            });

            builder.setView(view);
            Dialog dialog = builder.create();
            dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);
//        dialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
            dialog.setCanceledOnTouchOutside(true);
            if(dialog.getWindow() != null) dialog.getWindow().requestFeature(Window.FEATURE_NO_TITLE);
            return dialog;
        } catch (Exception e) {
            e.printStackTrace();
            dismissAllowingStateLoss();
        }

        return null;

    }

    @Override
    public void onStart() {
        super.onStart();
//        Dialog dialog = getDialog();
//        if (dialog != null && dialog.getWindow() != null) {
//            dialog.getWindow().setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
//            dialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
//        }
    }

    interface Callback {

        void onOkButtonClicked();

        void onCancelButtonClicked();
    }

}

==> visual-third-party-1.6.5-richnco-sources.jar: com/tenqube/visual_third/ui/NotificationDialogFragment.java <==
package com.tenqube.visual_third.ui;

import android.app.Dialog;
import android.graphics.Typeface;
import android.os.Build;
import android.os.Bundle;
import android.support.v4.app.DialogFragment;
import android.text.Html;
import android.view.View;
import android.view.Window;
import android.widget.Button;
import android.widget.TextView;

import com.tenqube.visual_third.R;
import com.tenqube.visual_third.util.FontUtil;

import static com.tenqube.visual_third.util.FontUtil.setAllTextView;


public class NotificationDialogFragment extends DialogFragment {

    public static final String TAG = NotificationDialogFragment.class.getSimpleName();


    public NotificationDialogFragment() {
        super();
    }

    Callback callback;

    public static NotificationDialogFragment newInstance(){
        return new NotificationDialogFragment();
    }

    public void setCallback(Callback callback) {
        this.callback = callback;
    }

    @Override
    public Dialog onCreateDialog(Bundle savedInstanceState) {

        try {

            android.app.AlertDialog.Builder builder = new android.app.AlertDialog.Builder(getContext());
            View view = getActivity().getLayoutInflater().inflate(R.layout.dialog_notification,null);
            setAllTextView(view);

            Typeface bold = FontUtil.getFont(getActivity(), FontUtil.MEDIUM);
            TextView title = view.findViewById(R.id.title);
            title.setTypeface(bold);

            TextView content = view.findViewById(R.id.content);
            String contentText = "<font color=\"#606060\">결제 관련 앱 알림 연동을 위해<br>휴대전화의</font>" +
                    "                        <font color=\"#ff8a00\">'설정 > 잠금화면 및 보안 ><br> 기타 보안 설정 > 알림 접근 허용'</font>"+
                    "                        <font color=\"#606060\">에서<br>굿리치를 허용해주세요.</font>";


            if (Build.VERSION.SDK_INT >= Build.VERSION_CODES.N) {
                content.setText(Html.fromHtml(contentText, Html.FROM_HTML_MODE_COMPACT));
            } else {
                content.setText(Html.fromHtml(contentText));
            }

            Button okButton = view.findViewById(R.id.ok);

            okButton.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    dismissAllowingStateLoss();
                    if(callback != null) {
                        callback.onOkButtonClicked();
                    }
                }
            });

            Button cancelButton = view.findViewById(R.id.cancel);

            cancelButton.setOnClickListener(new View.OnClickListener() {
                @Override
                public void onClick(View v) {
                    dismissAllowingStateLoss();
                    if(callback != null) {
                        callback.onCancelButtonClicked();
                    }
                }
            });

            builder.setView(view);
            Dialog dialog = builder.create();
            dialog.requestWindowFeature(Window.FEATURE_NO_TITLE);
//        dialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
            dialog.setCanceledOnTouchOutside(true);
            if(dialog.getWindow() != null) dialog.getWindow().requestFeature(Window.FEATURE_NO_TITLE);
            return dialog;
        } catch (Exception e) {
            e.printStackTrace();
            dismissAllowingStateLoss();
        }

        return null;

    }

    @Override
    public void onStart() {
        super.onStart();
//        Dialog dialog = getDialog();
//        if (dialog != null && dialog.getWindow() != null) {
//            dialog.getWindow().setLayout(ViewGroup.LayoutParams.MATCH_PARENT, ViewGroup.LayoutParams.WRAP_CONTENT);
//            dialog.getWindow().setBackgroundDrawable(new ColorDrawable(Color.TRANSPARENT));
//        }
    }

    interface Callback {

        void onOkButtonClicked();

        void onCancelButtonClicked();
    }

}
